@@ -2,10 +2,11 @@
 This hopes to recreate the functionality of the ACRG repo function
 footprints_data_merge
 """
-from pandas import Timestamp
-from xarray import Dataset, DataArray
-from typing import Optional, Tuple, Union, Dict, Any, cast
+from typing import Any, Dict, Optional, Tuple, Union, cast
+
 from openghg.dataobjects import FootprintData, ObsData
+from pandas import Timestamp
+from xarray import DataArray, Dataset
 
 # from openghg.dataobjects import FluxData
 
@@ -47,7 +48,7 @@ def single_site_footprint(
     Returns:
         xarray.Dataset
     """
-    from openghg.retrieve import get_obs_surface, get_footprint
+    from openghg.retrieve import get_footprint, get_obs_surface
     from openghg.util import timestamp_tzaware
 
     start_date = timestamp_tzaware(start_date)
@@ -554,12 +555,13 @@ def timeseries_HiTRes(
      TODO: mypy having trouble with different types options and incompatible types,
      included as Any for now.
     """
-    import numpy as np
-    import dask.array as da  # type: ignore
-    from tqdm import tqdm
-    from pandas import date_range
     from math import gcd
 
+    import dask.array as da  # type: ignore
+    import numpy as np
+    from pandas import date_range
+    from tqdm import tqdm
+
     fp_HiTRes = combined_dataset.fp_HiTRes
 
     # Calculate time resolution for both the flux and footprints data
